Documentation
¶
Index ¶
- type MockAuthenticator
- type MockAuthenticator_DynamicAPI_Call
- func (_c *MockAuthenticator_DynamicAPI_Call) Return(_a0 dynamic.Interface, _a1 error) *MockAuthenticator_DynamicAPI_Call
- func (_c *MockAuthenticator_DynamicAPI_Call) Run(run func()) *MockAuthenticator_DynamicAPI_Call
- func (_c *MockAuthenticator_DynamicAPI_Call) RunAndReturn(run func() (dynamic.Interface, error)) *MockAuthenticator_DynamicAPI_Call
- type MockAuthenticator_Expecter
- type MockAuthenticator_NativeAPI_Call
- func (_c *MockAuthenticator_NativeAPI_Call) Return(_a0 kubernetes.Interface, _a1 error) *MockAuthenticator_NativeAPI_Call
- func (_c *MockAuthenticator_NativeAPI_Call) Run(run func()) *MockAuthenticator_NativeAPI_Call
- func (_c *MockAuthenticator_NativeAPI_Call) RunAndReturn(run func() (kubernetes.Interface, error)) *MockAuthenticator_NativeAPI_Call
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MockAuthenticator ¶
MockAuthenticator is an autogenerated mock type for the Authenticator type
func NewMockAuthenticator ¶
func NewMockAuthenticator(t interface {
mock.TestingT
Cleanup(func())
}) *MockAuthenticator
NewMockAuthenticator creates a new instance of MockAuthenticator. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*MockAuthenticator) DynamicAPI ¶
func (_m *MockAuthenticator) DynamicAPI() (dynamic.Interface, error)
DynamicAPI provides a mock function with no fields
func (*MockAuthenticator) EXPECT ¶
func (_m *MockAuthenticator) EXPECT() *MockAuthenticator_Expecter
func (*MockAuthenticator) NativeAPI ¶
func (_m *MockAuthenticator) NativeAPI() (kubernetes.Interface, error)
NativeAPI provides a mock function with no fields
type MockAuthenticator_DynamicAPI_Call ¶
MockAuthenticator_DynamicAPI_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'DynamicAPI'
func (*MockAuthenticator_DynamicAPI_Call) Return ¶
func (_c *MockAuthenticator_DynamicAPI_Call) Return(_a0 dynamic.Interface, _a1 error) *MockAuthenticator_DynamicAPI_Call
func (*MockAuthenticator_DynamicAPI_Call) Run ¶
func (_c *MockAuthenticator_DynamicAPI_Call) Run(run func()) *MockAuthenticator_DynamicAPI_Call
func (*MockAuthenticator_DynamicAPI_Call) RunAndReturn ¶
func (_c *MockAuthenticator_DynamicAPI_Call) RunAndReturn(run func() (dynamic.Interface, error)) *MockAuthenticator_DynamicAPI_Call
type MockAuthenticator_Expecter ¶
type MockAuthenticator_Expecter struct {
// contains filtered or unexported fields
}
func (*MockAuthenticator_Expecter) DynamicAPI ¶
func (_e *MockAuthenticator_Expecter) DynamicAPI() *MockAuthenticator_DynamicAPI_Call
DynamicAPI is a helper method to define mock.On call
func (*MockAuthenticator_Expecter) NativeAPI ¶
func (_e *MockAuthenticator_Expecter) NativeAPI() *MockAuthenticator_NativeAPI_Call
NativeAPI is a helper method to define mock.On call
type MockAuthenticator_NativeAPI_Call ¶
MockAuthenticator_NativeAPI_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'NativeAPI'
func (*MockAuthenticator_NativeAPI_Call) Return ¶
func (_c *MockAuthenticator_NativeAPI_Call) Return(_a0 kubernetes.Interface, _a1 error) *MockAuthenticator_NativeAPI_Call
func (*MockAuthenticator_NativeAPI_Call) Run ¶
func (_c *MockAuthenticator_NativeAPI_Call) Run(run func()) *MockAuthenticator_NativeAPI_Call
func (*MockAuthenticator_NativeAPI_Call) RunAndReturn ¶
func (_c *MockAuthenticator_NativeAPI_Call) RunAndReturn(run func() (kubernetes.Interface, error)) *MockAuthenticator_NativeAPI_Call